pub enum CacheItemType {
Albums(Arc<Vec<LibraryAlbum>>),
AlbumTracks(Arc<Vec<LibraryTrack>>),
ArtistAlbums(Arc<Vec<LibraryAlbum>>),
Artist(Arc<LibraryArtist>),
Album(Arc<LibraryAlbum>),
}Variants
Albums(Arc<Vec<LibraryAlbum>>)
AlbumTracks(Arc<Vec<LibraryTrack>>)
ArtistAlbums(Arc<Vec<LibraryAlbum>>)
Artist(Arc<LibraryArtist>)
Album(Arc<LibraryAlbum>)
Implementations
Sourceimpl CacheItemType
impl CacheItemType
Sourcepub fn is_albums(&self) -> bool
pub fn is_albums(&self) -> bool
Returns true if this is a CacheItemType::Albums, otherwise false
Sourcepub fn as_albums_mut(&mut self) -> Option<&mut Arc<Vec<LibraryAlbum>>>
pub fn as_albums_mut(&mut self) -> Option<&mut Arc<Vec<LibraryAlbum>>>
Optionally returns mutable references to the inner fields if this is a CacheItemType::Albums, otherwise None
Sourcepub fn as_albums(&self) -> Option<&Arc<Vec<LibraryAlbum>>>
pub fn as_albums(&self) -> Option<&Arc<Vec<LibraryAlbum>>>
Optionally returns references to the inner fields if this is a CacheItemType::Albums, otherwise None
Sourcepub fn into_albums(self) -> Result<Arc<Vec<LibraryAlbum>>, Self>
pub fn into_albums(self) -> Result<Arc<Vec<LibraryAlbum>>, Self>
Returns the inner fields if this is a CacheItemType::Albums, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_album_tracks(&self) -> bool
pub fn is_album_tracks(&self) -> bool
Returns true if this is a CacheItemType::AlbumTracks, otherwise false
Sourcepub fn as_album_tracks_mut(&mut self) -> Option<&mut Arc<Vec<LibraryTrack>>>
pub fn as_album_tracks_mut(&mut self) -> Option<&mut Arc<Vec<LibraryTrack>>>
Optionally returns mutable references to the inner fields if this is a CacheItemType::AlbumTracks, otherwise None
Sourcepub fn as_album_tracks(&self) -> Option<&Arc<Vec<LibraryTrack>>>
pub fn as_album_tracks(&self) -> Option<&Arc<Vec<LibraryTrack>>>
Optionally returns references to the inner fields if this is a CacheItemType::AlbumTracks, otherwise None
Sourcepub fn into_album_tracks(self) -> Result<Arc<Vec<LibraryTrack>>, Self>
pub fn into_album_tracks(self) -> Result<Arc<Vec<LibraryTrack>>, Self>
Returns the inner fields if this is a CacheItemType::AlbumTracks, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_artist_albums(&self) -> bool
pub fn is_artist_albums(&self) -> bool
Returns true if this is a CacheItemType::ArtistAlbums, otherwise false
Sourcepub fn as_artist_albums_mut(&mut self) -> Option<&mut Arc<Vec<LibraryAlbum>>>
pub fn as_artist_albums_mut(&mut self) -> Option<&mut Arc<Vec<LibraryAlbum>>>
Optionally returns mutable references to the inner fields if this is a CacheItemType::ArtistAlbums, otherwise None
Sourcepub fn as_artist_albums(&self) -> Option<&Arc<Vec<LibraryAlbum>>>
pub fn as_artist_albums(&self) -> Option<&Arc<Vec<LibraryAlbum>>>
Optionally returns references to the inner fields if this is a CacheItemType::ArtistAlbums, otherwise None
Sourcepub fn into_artist_albums(self) -> Result<Arc<Vec<LibraryAlbum>>, Self>
pub fn into_artist_albums(self) -> Result<Arc<Vec<LibraryAlbum>>, Self>
Returns the inner fields if this is a CacheItemType::ArtistAlbums, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_artist(&self) -> bool
pub fn is_artist(&self) -> bool
Returns true if this is a CacheItemType::Artist, otherwise false
Sourcepub fn as_artist_mut(&mut self) -> Option<&mut Arc<LibraryArtist>>
pub fn as_artist_mut(&mut self) -> Option<&mut Arc<LibraryArtist>>
Optionally returns mutable references to the inner fields if this is a CacheItemType::Artist, otherwise None
Sourcepub fn as_artist(&self) -> Option<&Arc<LibraryArtist>>
pub fn as_artist(&self) -> Option<&Arc<LibraryArtist>>
Optionally returns references to the inner fields if this is a CacheItemType::Artist, otherwise None
Sourcepub fn into_artist(self) -> Result<Arc<LibraryArtist>, Self>
pub fn into_artist(self) -> Result<Arc<LibraryArtist>, Self>
Returns the inner fields if this is a CacheItemType::Artist, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_album_mut(&mut self) -> Option<&mut Arc<LibraryAlbum>>
pub fn as_album_mut(&mut self) -> Option<&mut Arc<LibraryAlbum>>
Optionally returns mutable references to the inner fields if this is a CacheItemType::Album, otherwise None
Sourcepub fn as_album(&self) -> Option<&Arc<LibraryAlbum>>
pub fn as_album(&self) -> Option<&Arc<LibraryAlbum>>
Optionally returns references to the inner fields if this is a CacheItemType::Album, otherwise None
Sourcepub fn into_album(self) -> Result<Arc<LibraryAlbum>, Self>
pub fn into_album(self) -> Result<Arc<LibraryAlbum>, Self>
Returns the inner fields if this is a CacheItemType::Album, otherwise returns back the enum in the Err case of the result